==> iam-1.131.0-sources.jar: software/amazon/awscdk/services/iam/UserAttributes.java <==
package software.amazon.awscdk.services.iam;

/**
 * Represents a user defined outside of this stack.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.42.0 (build 5f6b62c)", date = "2021-11-07T11:27:55.101Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.UserAttributes")
@software.amazon.jsii.Jsii.Proxy(UserAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface UserAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the user.
     * <p>
     * Format: arn:<partition>:iam::<account-id>:user/<user-name-with-path>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserArn();

    /**
     * @return a {@link Builder} of {@link UserAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link UserAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<UserAttributes> {
        private java.lang.String userArn;

        /**
         * Sets the value of {@link UserAttributes#getUserArn}
         * @param userArn The ARN of the user. This parameter is required.
         *                Format: arn:<partition>:iam::<account-id>:user/<user-name-with-path>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userArn(java.lang.String userArn) {
            this.userArn = userArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link UserAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public UserAttributes build() {
            return new Jsii$Proxy(userArn);
        }
    }

    /**
     * An implementation for {@link UserAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements UserAttributes {
        private final java.lang.String userArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.userArn = software.amazon.jsii.Kernel.get(this, "userArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String userArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.userArn = java.util.Objects.requireNonNull(userArn, "userArn is required");
        }

        @Override
        public final java.lang.String getUserArn() {
            return this.userArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("userArn", om.valueToTree(this.getUserArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iam.UserAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            UserAttributes.Jsii$Proxy that = (UserAttributes.Jsii$Proxy) o;

            return this.userArn.equals(that.userArn);
        }

        @Override
        public final int hashCode() {
            int result = this.userArn.hashCode();
            return result;
        }
    }
}

==> iam-1.133.0-sources.jar: software/amazon/awscdk/services/iam/UserAttributes.java <==
package software.amazon.awscdk.services.iam;

/**
 * Represents a user defined outside of this stack.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * IUser user = User.fromUserAttributes(this, "MyImportedUserByAttributes", UserAttributes.builder()
 *         .userArn("arn:aws:iam::123456789012:user/johnsmith")
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.45.0 (build 61747b6)", date = "2021-11-19T21:31:08.062Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.UserAttributes")
@software.amazon.jsii.Jsii.Proxy(UserAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface UserAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the user.
     * <p>
     * Format: arn:<partition>:iam::<account-id>:user/<user-name-with-path>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserArn();

    /**
     * @return a {@link Builder} of {@link UserAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link UserAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<UserAttributes> {
        java.lang.String userArn;

        /**
         * Sets the value of {@link UserAttributes#getUserArn}
         * @param userArn The ARN of the user. This parameter is required.
         *                Format: arn:<partition>:iam::<account-id>:user/<user-name-with-path>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userArn(java.lang.String userArn) {
            this.userArn = userArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link UserAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public UserAttributes build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link UserAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements UserAttributes {
        private final java.lang.String userArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.userArn = software.amazon.jsii.Kernel.get(this, "userArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.userArn = java.util.Objects.requireNonNull(builder.userArn, "userArn is required");
        }

        @Override
        public final java.lang.String getUserArn() {
            return this.userArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("userArn", om.valueToTree(this.getUserArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iam.UserAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            UserAttributes.Jsii$Proxy that = (UserAttributes.Jsii$Proxy) o;

            return this.userArn.equals(that.userArn);
        }

        @Override
        public final int hashCode() {
            int result = this.userArn.hashCode();
            return result;
        }
    }
}
